ncvue: A minimal GUI for a quick view of netcdf files.
       Aiming to be a drop-in replacement for ncview and panoply.

Created Nov 2020-Jan 2021 by Matthias Cuntz.

It is distributed under the MIT License (see LICENSE file).

Copyright (c) 2020-2025 Matthias Cuntz

Authors
-------

* `Matthias Cuntz`_, E-mail: mc (at) macu (dot) de

.. _Matthias Cuntz: https://github.com/mcuntz
